==> jdim_0.2.0.orig.tar.gz: jdim-0.2.0/docs/manual/2019.md <==
---
title: 更新履歴(2019年)
layout: default
---

&gt; [Top](../) &gt; [更新履歴]({{ site.baseurl }}/history/) &gt; {{ page.title }}

## {{ page.title }}


<a name="0.3.0-unreleased"></a>
### [0.3.0-unreleased](https://github.com/JDimproved/JDim/compare/JDim-v0.2.0...master) (unreleased)


<a name="JDim-v0.2.0"></a>
### [**JDim-v0.2.0** Release](https://github.com/JDimproved/JDim/releases/tag/JDim-v0.2.0) (2019-07-20)
主な変更点
- GTK3版をビルドするオプションを追加した(デフォルトはGTK2版)
- 最大表示可能レス数を固定(11000)から変更可能にした
- スレタイ検索のデフォルト設定を変更した(ff5ch.syoboi.jp)
- 動作環境の表示にTLSライブラリを追加した
- 旧設定ファイル(version < 1.9.5)のサポートを削除した

<a name="0.2.0-20190720"></a>
### [0.2.0-20190720](https://github.com/JDimproved/JDim/compare/79e90c8b2d...JDim-v0.2.0) (2019-07-20)
- Minor fixes
  ([#96](https://github.com/JDimproved/JDim/pull/96))
- Fix #90: Implement ENVIRONMENT::get_tlslib_version
  ([#94](https://github.com/JDimproved/JDim/pull/94))
- Tweak UI and configuration
  ([#93](https://github.com/JDimproved/JDim/pull/93))
- Add const qualifier to member functions
  ([#92](https://github.com/JDimproved/JDim/pull/92))
- Refactor SKELETON namespace
  ([#89](https://github.com/JDimproved/JDim/pull/89))
- Update constractor and destructor
  ([#88](https://github.com/JDimproved/JDim/pull/88))
- Improve ENVIRONMENT::get_wm() and ENVIRONMENT::get_wm_str()
  ([#87](https://github.com/JDimproved/JDim/pull/87))
- Fix test program build
  ([#85](https://github.com/JDimproved/JDim/pull/85))
- Fix #81: Add grouped configure option
  ([#84](https://github.com/JDimproved/JDim/pull/84))
- Fix #80: Deprecate configure option for CPU optimization
  ([#83](https://github.com/JDimproved/JDim/pull/83))
- Fix #79: Remove support for old version config files
  ([#82](https://github.com/JDimproved/JDim/pull/82))
- [DRAFT] Fix #45: Add unittest (Google Test)
  ([#78](https://github.com/JDimproved/JDim/pull/78))
- README.mdの整理
  ([#77](https://github.com/JDimproved/JDim/pull/77))
- Update manual to remove login and simplify history
  ([#75](https://github.com/JDimproved/JDim/pull/75))
- Fix to save thread list column width for GTK3
  ([#74](https://github.com/JDimproved/JDim/pull/74))
- Fix manual link (a.k.a. Create online manual [2/2])
  ([#72](https://github.com/JDimproved/JDim/pull/72))
- Create online manual [1/2]
  ([#69](https://github.com/JDimproved/JDim/pull/69))


<a name="0.1.0-20190430"></a>
### [0.1.0-20190430](https://github.com/JDimproved/JDim/compare/JDim-v0.1.0...79e90c8b2d) (2019-04-30)
- Fix #71: Deprecate gtkmm version less than 2.18
  ([#73](https://github.com/JDimproved/JDim/pull/73))
- Fix check button for usrcmdpref
  ([#70](https://github.com/JDimproved/JDim/pull/70))
- Fix \*BSD compile error
  ([#68](https://github.com/JDimproved/JDim/pull/68))
- Fix #60: Change default thread title search site (ff5ch.syoboi.jp)
  ([#65](https://github.com/JDimproved/JDim/pull/65))
- Tweak config dialog layout for GTK+3
  ([#64](https://github.com/JDimproved/JDim/pull/64))
- Use range-based for instead of MISC::count_chr()
  ([#63](https://github.com/JDimproved/JDim/pull/63))
- Fix #53: 長いスレッド(>11000レス?)を開くとクラッシュする不具合の修正
  ([#62](https://github.com/JDimproved/JDim/pull/62))
- Use std::unordered_set instead of std::vector for res information
  ([#61](https://github.com/JDimproved/JDim/pull/61))
- Fix released-event misfire for GtkGestureMultiPress
  ([#58](https://github.com/JDimproved/JDim/pull/58))
- Update function parameters for MISC::asc()
  ([#57](https://github.com/JDimproved/JDim/pull/57))
- Sanitize numeric character reference
  ([#56](https://github.com/JDimproved/JDim/pull/56))
- Fix #40: Make --with-gthread deprecated
  ([#55](https://github.com/JDimproved/JDim/pull/55))
- Add downloading dat from old URL
  ([#54](https://github.com/JDimproved/JDim/pull/54))
- Fix runtime warning for opening a thread since GTK+ 3.20
  ([#52](https://github.com/JDimproved/JDim/pull/52))
- Fix oniguruma detection for configure script
  ([#51](https://github.com/JDimproved/JDim/pull/51))
- font.cpp内のmallocをnewに置き換える
  ([#49](https://github.com/JDimproved/JDim/pull/49))
- Fix #46: キーワード抽出を行うとクラッシュする不具合の修正
  ([#48](https://github.com/JDimproved/JDim/pull/48))
- Avoid crash on extraction
  ([#47](https://github.com/JDimproved/JDim/pull/47))
- Add MATE and Cinnamon to ENVIRONMENT::get_wm()
  ([#44](https://github.com/JDimproved/JDim/pull/44))
- Replace JDLIB::hash_set_thread with std::unordered_set
  ([#43](https://github.com/JDimproved/JDim/pull/43))
- Fix variable type for assigning from std::string::find()
  ([#42](https://github.com/JDimproved/JDim/pull/42))
- Add touchscreen support (a.k.a. Add gtk3 support [2/2])
  ([#39](https://github.com/JDimproved/JDim/pull/39))
- Tweak JDLIB::JDSSL::connect()
  ([#38](https://github.com/JDimproved/JDim/pull/38))
- Set ellipsize to window status label since GTK+ 2.6
  ([#37](https://github.com/JDimproved/JDim/pull/37))
- Create CONTRIBUTING.md
  ([#36](https://github.com/JDimproved/JDim/pull/36))
- Fix gnutls reception
  ([#35](https://github.com/JDimproved/JDim/pull/35))
- Fix return types
  ([#34](https://github.com/JDimproved/JDim/pull/34))
- Debianでの開発環境について更新
  ([#33](https://github.com/JDimproved/JDim/pull/33))
- Fix JBBS board URL for setting board info
  ([#31](https://github.com/JDimproved/JDim/pull/31))
- Add gtk3 support [1/2]
  ([#30](https://github.com/JDimproved/JDim/pull/30))


<a name="JDim-v0.1.0"></a>
### [**JDim-v0.1.0** Release](https://github.com/JDimproved/JDim/releases/tag/JDim-v0.1.0) (2019-01-31)

<a name="0.1.0-20190129"></a>
### [0.1.0-20190129](https://github.com/JDimproved/JDim/compare/f6390b7f97...JDim-v0.1.0) (2019-01-29)
- Fix progname and docs
  ([#29](https://github.com/JDimproved/JDim/pull/29))
- Merge test branch into master
  ([#28](https://github.com/JDimproved/JDim/pull/28))
- Fix undefined behavior in JDLIB::hash_set_thread::get_key
  ([#27](https://github.com/JDimproved/JDim/pull/27))
- Add progname info
  ([#26](https://github.com/JDimproved/JDim/pull/26))
- Fix enabling digitlink in NodeTreeBase::parse_name
  ([#25](https://github.com/JDimproved/JDim/pull/25))


<a name="0.1.0-20190123"></a>
### [0.1.0-20190123](https://github.com/JDimproved/JDim/compare/bb608f24b1...f6390b7f97) (2019-01-23)

JDimへの名称変更に合わせてバージョン番号のリセットを行った。

- Update project
  ([#24](https://github.com/JDimproved/JDim/pull/24))
- Use -Wextra option
  ([#23](https://github.com/JDimproved/JDim/pull/23))
- Use override keyword
  ([#22](https://github.com/JDimproved/JDim/pull/22))
- Use compiler option "-pedantic" instead of "-pedantic-errors"
  ([#21](https://github.com/JDimproved/JDim/pull/21))
- Use flag pedantic errors
  ([#20](https://github.com/JDimproved/JDim/pull/20))
- Replace container type
  ([#19](https://github.com/JDimproved/JDim/pull/19))
- Fix compile warning
  ([#18](https://github.com/JDimproved/JDim/pull/18))
- Fix access violation in DBTREE::NodeTreeBase::receive_data()
  ([#17](https://github.com/JDimproved/JDim/pull/17))

==> jdim_0.10.1.orig.tar.gz: jdim-0.10.1/docs/manual/2019.md <==
---
title: 更新履歴(2019年)
layout: default
---

&gt; [Top](../) &gt; [更新履歴]({{ site.baseurl }}/history/) &gt; {{ page.title }}

## {{ page.title }}


<a name="0.2.0-20191027"></a>
### [0.2.0-20191027](https://github.com/JDimproved/JDim/compare/JDim-v0.2.0...362b797d53f) (2019-10-27)
- Remove deprecated cpu optimization options
  ([#140](https://github.com/JDimproved/JDim/pull/140))
- Fix scrollbar behaviors for thread view on GTK3
  ([#136](https://github.com/JDimproved/JDim/pull/136))
- Set ellipsize to dialog info label
  ([#135](https://github.com/JDimproved/JDim/pull/135))
- Use Gtk::FontChooserDialog instead of Gtk::FileSelectionDialog on GTK3
  ([#134](https://github.com/JDimproved/JDim/pull/134))
- Improve displaying tooltip for bbs list/thread list
  ([#133](https://github.com/JDimproved/JDim/pull/133))
- Improve displaying manual on github.com
  ([#132](https://github.com/JDimproved/JDim/pull/132))
- Fix GTKMM_CHECK_VERSION macro
  ([#131](https://github.com/JDimproved/JDim/pull/131))
- Fix tooltips which are not near mouse pointer on bbs list/thread list for GTK3
  ([#128](https://github.com/JDimproved/JDim/pull/128))
- Add github links for previous version manuals
  ([#130](https://github.com/JDimproved/JDim/pull/130))
- Revert "[WORKAROUND] Fix build error for manual"
  ([#129](https://github.com/JDimproved/JDim/pull/129))
- Use range-based for
  ([#126](https://github.com/JDimproved/JDim/pull/126))
- Refactor string operation
  ([#125](https://github.com/JDimproved/JDim/pull/125))
- Update requirements for dependencies (gtkmm >= 2.18)
  ([#124](https://github.com/JDimproved/JDim/pull/124))
- [WORKAROUND] Fix build error for manual
  ([#127](https://github.com/JDimproved/JDim/pull/127))
- Fix mouse button config to set Button5 correctly
  ([#123](https://github.com/JDimproved/JDim/pull/123))
- Implement tilt wheel for DragTreeView on GTK3
  ([#122](https://github.com/JDimproved/JDim/pull/122))
- Fix bug which is applied ascii art font falsely on GTK3
  ([#121](https://github.com/JDimproved/JDim/pull/121))
- Replace `gcry_md_hash_buffer` with `gnutls_hash_fast`
  ([#120](https://github.com/JDimproved/JDim/pull/120))
- Add a note of bug which is applied AA font falsely to thread view
  ([#119](https://github.com/JDimproved/JDim/pull/119))
- Add snapcraft.yaml
  ([#118](https://github.com/JDimproved/JDim/pull/118))
- Improve tab switch by mouse wheel for image view
  ([#117](https://github.com/JDimproved/JDim/pull/117))
- Implement tab switch by mouse wheel for GTK3
  ([#114](https://github.com/JDimproved/JDim/pull/114))
- Add smooth scroll event to enable mouse wheel on GTK3
  ([#113](https://github.com/JDimproved/JDim/pull/113))
- Fix configure args info to include "without" and "disable" options
  ([#112](https://github.com/JDimproved/JDim/pull/112))
- Fix #109: Remove cache root config providing compatible with old version
  ([#111](https://github.com/JDimproved/JDim/pull/111))
- Fix markdown format for the table of cache directory priority
  ([#115](https://github.com/JDimproved/JDim/pull/115))
- Fix #104: Implement XDG Base Directory support for cache
  ([#108](https://github.com/JDimproved/JDim/pull/108))
- Fix #103: Add jdim.metainfo.xml
  ([#107](https://github.com/JDimproved/JDim/pull/107))
- Fix #102: Update application icon installation
  ([#106](https://github.com/JDimproved/JDim/pull/106))
- Fix #101 Remove subversion support
  ([#105](https://github.com/JDimproved/JDim/pull/105))
- add CPPFLAGS, CXXFLAGS and LDFLAGS for test
  ([#100](https://github.com/JDimproved/JDim/pull/100))
- Fix #98: Add travis-ci.com configuration
  ([#99](https://github.com/JDimproved/JDim/pull/99))


<a name="JDim-v0.2.0"></a>
### [**JDim-v0.2.0** Release](https://github.com/JDimproved/JDim/releases/tag/JDim-v0.2.0) (2019-07-20)
主な変更点
- GTK3版をビルドするオプションを追加した(デフォルトはGTK2版)
- 最大表示可能レス数を固定(11000)から変更可能にした
- スレタイ検索のデフォルト設定を変更した(ff5ch.syoboi.jp)
- 動作環境の表示にTLSライブラリを追加した
- 旧設定ファイル(version < 1.9.5)のサポートを削除した

<a name="0.2.0-20190720"></a>
### [0.2.0-20190720](https://github.com/JDimproved/JDim/compare/79e90c8b2d...JDim-v0.2.0) (2019-07-20)
- Release 0.2.0
  ([#97](https://github.com/JDimproved/JDim/pull/97))
- Minor fixes
  ([#96](https://github.com/JDimproved/JDim/pull/96))
- Fix #90: Implement ENVIRONMENT::get_tlslib_version
  ([#94](https://github.com/JDimproved/JDim/pull/94))
- Tweak UI and configuration
  ([#93](https://github.com/JDimproved/JDim/pull/93))
- Add const qualifier to member functions
  ([#92](https://github.com/JDimproved/JDim/pull/92))
- Refactor SKELETON namespace
  ([#89](https://github.com/JDimproved/JDim/pull/89))
- Update constractor and destructor
  ([#88](https://github.com/JDimproved/JDim/pull/88))
- Improve ENVIRONMENT::get_wm() and ENVIRONMENT::get_wm_str()
  ([#87](https://github.com/JDimproved/JDim/pull/87))
- Fix test program build
  ([#85](https://github.com/JDimproved/JDim/pull/85))
- Fix #81: Add grouped configure option
  ([#84](https://github.com/JDimproved/JDim/pull/84))
- Fix #80: Deprecate configure option for CPU optimization
  ([#83](https://github.com/JDimproved/JDim/pull/83))
- Fix #79: Remove support for old version config files
  ([#82](https://github.com/JDimproved/JDim/pull/82))
- [DRAFT] Fix #45: Add unittest (Google Test)
  ([#78](https://github.com/JDimproved/JDim/pull/78))
- README.mdの整理
  ([#77](https://github.com/JDimproved/JDim/pull/77))
- Update manual to remove login and simplify history
  ([#75](https://github.com/JDimproved/JDim/pull/75))
- Fix to save thread list column width for GTK3
  ([#74](https://github.com/JDimproved/JDim/pull/74))
- Fix manual link (a.k.a. Create online manual [2/2])
  ([#72](https://github.com/JDimproved/JDim/pull/72))
- Create online manual [1/2]
  ([#69](https://github.com/JDimproved/JDim/pull/69))


<a name="0.1.0-20190430"></a>
### [0.1.0-20190430](https://github.com/JDimproved/JDim/compare/JDim-v0.1.0...79e90c8b2d) (2019-04-30)
- Fix #71: Deprecate gtkmm version less than 2.18
  ([#73](https://github.com/JDimproved/JDim/pull/73))
- Fix check button for usrcmdpref
  ([#70](https://github.com/JDimproved/JDim/pull/70))
- Fix \*BSD compile error
  ([#68](https://github.com/JDimproved/JDim/pull/68))
- Fix #60: Change default thread title search site (ff5ch.syoboi.jp)
  ([#65](https://github.com/JDimproved/JDim/pull/65))
- Tweak config dialog layout for GTK+3
  ([#64](https://github.com/JDimproved/JDim/pull/64))
- Use range-based for instead of MISC::count_chr()
  ([#63](https://github.com/JDimproved/JDim/pull/63))
- Fix #53: 長いスレッド(>11000レス?)を開くとクラッシュする不具合の修正
  ([#62](https://github.com/JDimproved/JDim/pull/62))
- Use std::unordered_set instead of std::vector for res information
  ([#61](https://github.com/JDimproved/JDim/pull/61))
- Fix released-event misfire for GtkGestureMultiPress
  ([#58](https://github.com/JDimproved/JDim/pull/58))
- Update function parameters for MISC::asc()
  ([#57](https://github.com/JDimproved/JDim/pull/57))
- Sanitize numeric character reference
  ([#56](https://github.com/JDimproved/JDim/pull/56))
- Fix #40: Make --with-gthread deprecated
  ([#55](https://github.com/JDimproved/JDim/pull/55))
- Add downloading dat from old URL
  ([#54](https://github.com/JDimproved/JDim/pull/54))
- Fix runtime warning for opening a thread since GTK+ 3.20
  ([#52](https://github.com/JDimproved/JDim/pull/52))
- Fix oniguruma detection for configure script
  ([#51](https://github.com/JDimproved/JDim/pull/51))
- font.cpp内のmallocをnewに置き換える
  ([#49](https://github.com/JDimproved/JDim/pull/49))
- Fix #46: キーワード抽出を行うとクラッシュする不具合の修正
  ([#48](https://github.com/JDimproved/JDim/pull/48))
- Avoid crash on extraction
  ([#47](https://github.com/JDimproved/JDim/pull/47))
- Add MATE and Cinnamon to ENVIRONMENT::get_wm()
  ([#44](https://github.com/JDimproved/JDim/pull/44))
- Replace JDLIB::hash_set_thread with std::unordered_set
  ([#43](https://github.com/JDimproved/JDim/pull/43))
- Fix variable type for assigning from std::string::find()
  ([#42](https://github.com/JDimproved/JDim/pull/42))
- Add touchscreen support (a.k.a. Add gtk3 support [2/2])
  ([#39](https://github.com/JDimproved/JDim/pull/39))
- Tweak JDLIB::JDSSL::connect()
  ([#38](https://github.com/JDimproved/JDim/pull/38))
- Set ellipsize to window status label since GTK+ 2.6
  ([#37](https://github.com/JDimproved/JDim/pull/37))
- Create CONTRIBUTING.md
  ([#36](https://github.com/JDimproved/JDim/pull/36))
- Fix gnutls reception
  ([#35](https://github.com/JDimproved/JDim/pull/35))
- Fix return types
  ([#34](https://github.com/JDimproved/JDim/pull/34))
- Debianでの開発環境について更新
  ([#33](https://github.com/JDimproved/JDim/pull/33))
- Fix JBBS board URL for setting board info
  ([#31](https://github.com/JDimproved/JDim/pull/31))
- Add gtk3 support [1/2]
  ([#30](https://github.com/JDimproved/JDim/pull/30))


<a name="JDim-v0.1.0"></a>
### [**JDim-v0.1.0** Release](https://github.com/JDimproved/JDim/releases/tag/JDim-v0.1.0) (2019-01-31)

<a name="0.1.0-20190129"></a>
### [0.1.0-20190129](https://github.com/JDimproved/JDim/compare/f6390b7f97...JDim-v0.1.0) (2019-01-29)
- Fix progname and docs
  ([#29](https://github.com/JDimproved/JDim/pull/29))
- Merge test branch into master
  ([#28](https://github.com/JDimproved/JDim/pull/28))
- Fix undefined behavior in JDLIB::hash_set_thread::get_key
  ([#27](https://github.com/JDimproved/JDim/pull/27))
- Add progname info
  ([#26](https://github.com/JDimproved/JDim/pull/26))
- Fix enabling digitlink in NodeTreeBase::parse_name
  ([#25](https://github.com/JDimproved/JDim/pull/25))


<a name="0.1.0-20190123"></a>
### [0.1.0-20190123](https://github.com/JDimproved/JDim/compare/bb608f24b1...f6390b7f97) (2019-01-23)

JDimへの名称変更に合わせてバージョン番号のリセットを行った。

- Update project
  ([#24](https://github.com/JDimproved/JDim/pull/24))
- Use -Wextra option
  ([#23](https://github.com/JDimproved/JDim/pull/23))
- Use override keyword
  ([#22](https://github.com/JDimproved/JDim/pull/22))
- Use compiler option "-pedantic" instead of "-pedantic-errors"
  ([#21](https://github.com/JDimproved/JDim/pull/21))
- Use flag pedantic errors
  ([#20](https://github.com/JDimproved/JDim/pull/20))
- Replace container type
  ([#19](https://github.com/JDimproved/JDim/pull/19))
- Fix compile warning
  ([#18](https://github.com/JDimproved/JDim/pull/18))
- Fix access violation in DBTREE::NodeTreeBase::receive_data()
  ([#17](https://github.com/JDimproved/JDim/pull/17))
